#
# spec file for package highlight
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           highlight
Version:        3.31
Release:        3.2
Summary:        Universal Source Code to Formatted Text Converter
License:        GPL-3.0+
Group:          Development/Tools/Other
Url:            http://www.andre-simon.de/
Source0:        http://www.andre-simon.de/zip/%{name}-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE highlight-2.10-makefile_suse.patch
Patch0:         highlight-2.10-makefile_suse.patch
# PATCH-FIX-OPENSUSE highlight-3.30-use_optflags.patch
Patch1:         highlight-3.30-use_optflags.patch
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libqt4-devel
BuildRequires:  lua-devel
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A utility that converts sourcecode to HTML, XHTML, RTF, LaTeX, TeX, XML or ANSI
escape sequences with syntax highlighting.
It supports several programming and markup languages.
Language descriptions are configurable and support regular expressions.
The utility offers indentation and reformatting capabilities.
It is easily possible to create new language definitions and colour themes.

%package gui
Summary:        Universal Source Code to Formatted Text Converter
Group:          Development/Tools/Other
Requires:       %{name} = %{version}

%description gui
A utility that converts sourcecode to HTML, XHTML, RTF, LaTeX, TeX, XML or ANSI
escape sequences with syntax highlighting.
It supports several programming and markup languages.
Language descriptions are configurable and support regular expressions.
The utility offers indentation and reformatting capabilities.
It is easily possible to create new language definitions and colour themes.

%prep
%setup -q
%patch0 -p1
%patch1

%build
make QMAKE="qmake" OPTFLAGS="%{optflags}" %{?_smp_mflags}
make gui QMAKE="qmake" OPTFLAGS="%{optflags}" %{?_smp_mflags}

%install
%makeinstall install-gui
%suse_update_desktop_file -G "Text converter" -r %{name} Utility TextEditor

L="$PWD/%{name}.lang"
LDIR="%{_datadir}/%{name}/gui_files/l10n"
echo -n >"$L"
pushd "%{buildroot}$LDIR"
/bin/ls -1 *.qm | while read qm; do
    [ -f "$qm" ] || continue
    l="${qm#*_}"
    l="${l%.qm}"
    echo "%lang($l) $LDIR/$qm" >>"$L"
done
popd

%files
%defattr(-,root,root,-)
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/*
%{_bindir}/%{name}
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/%{name}/filetypes.conf
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/langDefs
%{_datadir}/%{name}/langDefs/*.lang
%dir %{_datadir}/%{name}/plugins
%{_datadir}/%{name}/plugins/*.lua
%dir %{_datadir}/%{name}/themes
%{_datadir}/%{name}/themes/*.theme
%{_mandir}/man1/%{name}.1%{ext_man}
%exclude %{_docdir}/%{name}/INSTALL

%files gui -f "%{name}.lang"
%defattr(-,root,root,-)
%{_bindir}/%{name}-gui
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/%{name}/gui_files
%dir %{_datadir}/%{name}/gui_files/ext
%{_datadir}/%{name}/gui_files/ext/fileopenfilter.conf
%dir %{_datadir}/%{name}/gui_files/l10n
%{_datadir}/pixmaps/%{name}.xpm

%changelog
* Mon Aug  1 2016 antoine.belvire@laposte.net
- Update to 3.31:
  * Revise documentation
  * GUI: fix minor layout issues
- Change arguments order for suse_update_desktop_file: GenericName
  was not set.
* Wed Jul  6 2016 antoine.belvire@laposte.net
- Update to 3.30:
  * The data directory can be defined with the HIGHLIGHT_DATADIR
    environment variable
  * Fix RTF output of UTF-8 input; needs input encoding set to
    utf-8
  * Fix XML comment recognition
  * Data search directories is appended to the result of
  - -list-scripts
  * Revise older syntax definitions
  * Update base URLs of bash_ref_linuxmanpages and
    cpp_ref_qtproject plug-ins
  * GUI: add system copy and paste shortcuts for clipboard
    functions
- Remove highlight-3.29-use_optflags.patch
- Add highlight-3.30-use_optflags.patch (rebased)
* Tue May 24 2016 antoine.belvire@laposte.net
- Update to 3.29:
  * Add Ansible Yaml definition (thanks to Raphael Droz)
  * Add Chapel definition (thanks to Lydia Duncan)
  * Fix gcc 6 warnings about deprecated auto_ptr usage
  * GUI: fix style file output if "write to source directory"
    option is checked (thanks to Jim Pattee)
- Remove highlight-3.25-use_optflags.patch
- Add highlight-3.29-use_optflags.patch (rebased)
* Mon Mar 21 2016 antoine.belvire@laposte.net
- Fix licence in spec file: it's GPL-3.0+ since v2.10.
* Sat Mar 12 2016 antoine.belvire@laposte.net
- Update to 3.28:
  * add support of Pascal, Lua, Ruby and C# regions in
    outhtml_codefold.lua
  * improve outhtml_codefold.lua to handle embedded languages
  * add string delimiters in the Ruby definition
  * add new AssertEqualLength flag in string section of language
    definitions
  * improve heredoc parsing
  * fix Lua multiline string recognition
  * improve SVG whitespace output (patch by Paul de Vrieze)
  * add Nim and mIRC Scripting definitions
- Changes from 3.27:
  * improve outhtml_codefold.lua to ignore brackets on the same
    line
  * add RTF output to mark_lines.lua
  * fix Powershell and NSIS definitions
  * add JSON and Github Markdown definitions
  * CLI: add --keep-injections option to force plugin injection
    output with -f
  * GUI: add keep injections checkbox
  * GUI: fix crash after removing selected plugins
- Changes from 3.26:
  * add HL_REJECT state to be used in a OnStateChange function
  * add DecorateLineBegin and DecorateLineEnd hooks
  * add mark_lines.lua, outhtml_codefold.lua, comment_links.lua
    plug-ins
  * fix font face in ODT output
  * fix Operators parameter in frink.lang and oorexx.lang
  * fix regular expression parsing within strings for JS, Perl and
    Ruby
  * CLI: add --page-color option to include a page color in RTF
    output
  * GUI: add RTF page color option
- Remove LDFLAGS+="-s" from spec file: don't strip the binaries,
  the build service will do it and will create -debuginfo
  packages
* Sun Dec 27 2015 antoine.belvire@laposte.net
- Update to 3.25:
  * add new SVG definition to support embedded scripting
  * improve js.lang, css.lang, scss.lang, less.lang, tsql.lang
  * modifiy HTML ordered list output to work better with new plug-ins
  * rename plug-in variable HL_INPUT_FILE to HL_PLUGIN_PARAM
  * CLI: rename --plug-in-read option to --plug-in-param
  * GUI: update plug-in parameter label and tool-tips
  * GUI: fix minor issues
- Delete highlight-3.22-use_optflags.patch
- Add highlight-3.25-use_optflags.patch (rebased)
* Fri Nov  6 2015 antoine.belvire@laposte.net
- Update to 3.24:
  * fix TeX output for cweb documents (patch by Ingo Krabbe)
  * fix string interpolation in bat.lang
  * add reduce_filesize.lua, outhtml_add_shadow.lua,
    outhtml_add_background_svg.lua, outhtml_add_background_stripes.lua,
    outhtml_add_line.lua plug-ins
  * add TCL extension in examples/tcl
  * add kotlin.lang, nginx.lang and julia.lang
  * update php.lang to include version 7 keywords
  * update ceylon.lang to include version 1.2 keywords
  * update scripts in examples directory
  * CLI: style-infile option marked as deprecated
  * GUI: shorten paths in file input lists
* Thu Sep 17 2015 antoine.belvire@laposte.net
- Update to 3.23:
  * add rs.lang
  * add conf.lang (thanks to Victor Ananjevsky)
  * add some extensions in filetypes.conf (patch by Victor Ananjevsky)
  * fix Matlab definition and style (thanks to Justin Pearson)
  * CLI: fix --list-scripts with unknown argument (thanks to Jens Schleusener)
* Wed May 27 2015 antoine.belvire@laposte.net
- Update to 3.22:
  * update astyle code to release 2.05.1
  * fix shebang recognition (thanks to Victor Ananjevsky)
  * GUI: add option to define line numbering start
  * see /usr/share/doc/packages/highlight/ChangeLog for changes
    introduced in version 3.21
- Update spec file:
  * remove lua 5.1 compatibility patch for openSUSE < 12.2
  * rebase highlight-use_optflags.patch
  * exclude INSTALL file from doc
  * clean with spec-cleaner
* Sun Feb  1 2015 antoine.belvire@laposte.net
- Update to 3.20:
  * updated astyle code to release 2.05
  * added astyle reformatting style vtk
  * see /usr/share/doc/packages/highlight/ChangeLog for changes
    introduced in 3.13 to 3.19 versions
- Update spec file:
  * use lua-devel instead of lua51-devel (Lua 5.2 support was
    introduced with highlight 3.15)
  * add lua 5.1 compatibility patch for openSUSE < 12.2
  * explicitly strip binary with LDFLAGS="-s" (it's now
    disabled by default for MacOS compatibility reasons)
  * fix rpmlint license error
  * update patches
* Tue Nov 20 2012 vjt@openssl.it
- Use lua51 for OpenSUSE 12.2 and upwards.
* Mon Nov 19 2012 vjt@openssl.it
- update to 3.12
* Sat Jun  4 2011 pascal.bleser@opensuse.org
- use %%{optflags}
- update to 3.5:
  * updated astyle code to release 2.02
  * fixed --force option
* Sat Apr  2 2011 detlef@links2linux.de
- new upstream version <3.4>
  * added support for ABC, Algol, AS/400 CL, BCPL,  Limbo, Gambas, JavaFX,
    RPG, Transact-SQL, PL/Perl, PL/Tcl, PL/Python, Charmm
  * fixed web plugins (Serendipity, DokuWiki, Wordpress)
  * fixed BBCode closing tag order
  * GUI: Updated Czech translation (thanks to Pavel Fric)
* Thu Dec 30 2010 detlef@links2linux.de
- new upstream version <3.3>
  * updated astyle code to release 2.01
  * fixed overwriting of files with the same name in recursive batch mode
    (thanks to Ramanathan U.)
  * added DataDir class to SWIG interface (patch by David Bremner)
  * added Andes theme (thanks to Roger Sperberg)
  * enabled deprecated @highlight pass-through (suggested by David Bremner)
  * dropped oceandeep theme
  * updated documentation
* Sat Nov 13 2010 detlef@links2linux.de
- new upstream version <3.2>
  * added plug-in function AddKeyword (suggested by Michael Serrano)
  * language definitions are cached instead of being reloaded if input syntax
    changes
  * added keyword group ID parameter to the plug-in function OnStateChange
  * added plug-in script bash_functions.lua
  * added theme description in output style's comment
  * added enum and union keywords in c.lang (thanks to Thiago)
  * added dl linking flag in Makefile to fix Debian build error.
    (thanks to Michael Serrano)
  * added NDEBUG flag in makefile to disable asserts
* Wed Aug 25 2010 detlef@links2linux.de
- new upstream version <3.1>
* Fri Apr  2 2010 detlef@links2linux.de
- new upstream version <2.16>
  * updated astyle code to release 1.24
  * added indentation styles 1tbs and horstmann
  * added --no-trailing-nl switch (suggested by Adiel Mittmann)
  * added Modula2 definition (thanks to Benjamin Kowarsch)
  * added EBNF definition (thanks to Mate Ory)
  * added ABNF, AutoHotKey, BBCode and Clean language definitions
  * updated C++ definition to support C++0x syntax
  * added StartupNotify switch in desktop file (patch by Jochen Schmitt)
* Sat Feb 27 2010 detlef@links2linux.de
- new upstream version <2.15>
  * improved HTML nested language patterns (thanks to Simone)
  * improved Rexx and PL1 definitions (thabnks to Robert Prins)
  * added support for NXC and NBC
  * GUI: added copy and paste support (thanks to Torsten Flamminger)
  * GUI: fixed preview of UTF-8 input
* Mon Jan 25 2010 detlef@links2linux.de
- new upstream version <2.14>
  * fixed Rexx output (thanks to Marc Hessling)
  * added support for Go and Pure
  * added support for BNF (thanks to Julien Fontanet)
  * updated Logtalk definition (thanks to Paulo Moura)
  * updated THE theme  (thanks to Marc Hessling)
  * CLI: --quiet switch supresses "Unknown source file extension" error
    (suggested by Nathan Gray)
* Tue Oct 13 2009 detlef@links2linux.de
- new upstream version <2.13>
  * Fixed SVG output (thanks to Xico)
  * GUI: added new icon
* Fri Sep 11 2009 detlef@links2linux.de
- new upstream version <2.12>
  * fixed bug with $INCLUDE statement
  * fixed ctags file parsing
  * added nested language recognition within a source file (suggested by Pavel Striz)
  * added $NESTED statement to language definitions (pas, html, tex)
  * added support for F# (fs.lang)
  * added support for haXe (hx.lang)
  * improved various language definitions
  * revised documentation
  * LIB: added version to shared lib output name
  * CLI: added options --start-nested and --print-style
* Sat Aug  1 2009 detlef@links2linux.de
- new upstream version <2.11>
  * added BBCode output option (--bbcode, suggested by Qui Peccavit)
  * added new --delim-cr option to cope with MacOS 9 files
    (suggested by Steven Haddock)
  * added shared lib target (make lib-shared, suggested by Dario Teixeira)
  * list of installed languages (--list-langs) was enhanced to include mapped file
    extensions (suggested by Martin Kammerlander)
  * improved many colour themes using Agave (agave.sf.net)
* Wed Jul 22 2009 detlef@links2linux.de
- new upstream version <2.10>
  * fixed CR parsing bug on MacOS (thanks to Shiro Wilde)
  * fixed SWIG makefile (thanks to David Bremner)
  * license changed from GPLv2 to GPLv3 (incl. included libs)
  * updated Artistic Style lib to version 1.23
  * new indentation schemes: stroustrup, whitesmith, banner
  * removed indentSchemes and helpmsg directories
  * removed README_INDENT
  * replaced ide-devcpp theme by a new jedit theme
  * added support for Interactive Data Language (idlang, thanks to Roberto
    Mendoza)
  * added support for Rebol, Oz, Mercury, Zonnon, ATS (Applied Type System),
    CHILL, NetRexx, Inno Setup and INTERLIS
  * added pp, rjs, jnlp, groovy, gnad, es, sblc, ooc, gst, sq extensions
    to filetypes.conf
  * improved Prolog, Pike, Oberon, Nice, Java, Lisp, Lua, Haskell, C# and SML
    definitions
  * improved spec.lang for RPM (thanks to Luoyi Ly)
  * CLI: option --help-lang is deprecated
  * API: dropped setSpecialOptions(), renamed initializing methods to init*
- 2.9
  * added more customized boxes for the LaTeX --pretty-symbols switch
    (thanks to Romain Francois)
  * GUI: fixed makefile to pass costum paths to the Qt project makefile
    (thanks to Joerg Germeroth)
  * GUI: reduced window height (thanks to Fidel Barrera)
  * GUI: added Spanish translation (thanks to Fidel Barrera)
  * GUI: added drag and drop for input files
- 2.8
  * added --pretty-symbols option to improve LaTeX output quality of tilde and
    braces (thanks to Romain Francois)
  * omitted warning message if --syntax parameter is contained in the --skip list
    (thanks to Bob Smith)
  * included language descriptions in --list-langs output
  * dropped dependency of --replace-quotes and --fragment options
  * enhanced Python SWIG example (testmod.py)
  * added qmake language definition
  * fixed SWIG scripts (thanks to David Bremner)
  * fixed gcc 4.4 compilation (patch by Jochen Schmitt)
  * dropped core/html32generator.*
  * dropped src/gui (wxWidgets based interface)
  * GUI: rewrote the user interface using Qt
* Wed Jan 14 2009 detlef@links2linux.de
- new upstream version <2.7>
* Sat Nov  1 2008 detlef@links2linux.de
- new upstream version <2.6.14>
  * added --ctags-file option to add tooltips with meta information in HTML output
  * added options to improve compatibility with GNU source-highlight:
  - -doc, --no-doc, --tab, --css, --output-dir, --failsafe, --out-format,
  - -src-lang, --line-number, --line-number-ref
  * fixed ADA95, C#, Eiffel, Fortran, TCL, Bash definitions
  * added Vala language definition
  * added several file suffixes to filetypes.conf
  * fixed gcc 4.3 compilation issues (patch by Detlef Reichelt)
  * fixed race condition in makefile (patch by Jochen Schmitt)
  * added exit condition if input path matches output path (suggested by James Haefner)
  * GUI: added ctags file selection options (only wx2.9 version)
* Fri Oct  3 2008 detlef@links2linux.de
- new upstream version <2.6.13>
- add gcc43 patch
  * added --skip option to ignore unknown file types (suggested by Bob Smith)
  * added Haskell LHS language definition (suggested by Sebastian Roeder)
  * added regex description for Perl and Ruby definitions
  * improved Bison, Paradox, SML, Snobol, Verilog definitions
  * renamed snobol.lang to sno.lang
  * updated Artistic Style lib to version 1.22
  * replaced dirstream lib by a faster file globbing method (invoked with --batch-recursive)
  * support for USE_FN_MATCH compile flag was dropped
  * Makefile generates libhighlight.a (suggested by Adiel Mittmann)
  * updated SWIG makefile and documentation
* Thu Aug  7 2008 detlef@links2linux.de
- new upstream version <2.6.12>
  * added RTF character stylesheet option (suggested by Klaus Nordby)
  * fixed filetypes.conf path in RPM specfile (thanks to Nikita Borodikhin)
* Fri Jul 18 2008 detlef@links2linux.de
- new upstream version <2.6.11>
  * added SVG output option (--svg)^
  * reassigned -G short option from --class-name to --svg^
  * fixed various makefile issues (patches by Samuli Suominen)^
  * added highlight.desktop file (suggested by Samuli Suominen)^
  * GUI: added SVG and font selection options (only wx2.9 version)^
  * GUI: reduced window height by hiding format specific input controls^
  * updated highlight.spec to compile wx2.9 GUI^
* Sat May 10 2008 detlef@links2linux.de
- new upstream version <2.6.10>
* Fri Mar 28 2008 detlef@links2linux.de
- new upstream version <2.6.9>
* Fri Feb  1 2008 detlef@links2linux.de
- new upstream version <2.6.8>
* Tue Dec 11 2007 detlef@links2linux.de
- new upstream version <2.6.6>
* Fri Oct  5 2007 detlef@links2linux.de
- new upstream version <2.6.5>
* Sat Sep 15 2007 detlef@links2linux.de
- new upstream version <2.6.4>
* Fri Sep  7 2007 detlef@links2linux.de
- new upstream version <2.6.3>
* Mon Jul 23 2007 detlef@links2linux.de
- new upstream version <2.6.2>
* Thu Jun 28 2007 detlef@links2linux.de
- new upstream version <2.6.1>
* Thu May 10 2007 detlef@links2linux.de
- new upstream version
* Fri Nov 17 2006 detlef@links2linux.de
- new upstream version
* Sat Aug  5 2006 detlef@links2linux.de
- first build for packman
